export type ResourceType = 'database' | 'queue';
export interface EnvField {
    key: string;
    defaultValue: string;
    comment?: string;
    resource?: ResourceType;
    required?: boolean;
}
export declare function detectResourceFromKey(key: string): ResourceType | undefined;
export declare function parseEnvExample(content: string): EnvField[];
//# sourceMappingURL=env-example.d.ts.map