/**
 * Create a minimal logger that works in any environment (browser + server).
 * Used as default when no logger is provided.
 */
export function createMinimalLogger() {
    const noop = () => { };
    const logger = {
        trace: noop,
        debug: noop,
        info: console.log.bind(console),
        warn: console.warn.bind(console),
        error: console.error.bind(console),
        fatal(...args) {
            console.error(...args);
            throw new Error(String(args[0] ?? 'fatal'));
        },
        child() {
            return createMinimalLogger();
        },
    };
    return logger;
}
//# sourceMappingURL=logger.js.map